\name{encTest3-package}
\alias{encTest3-package}
\alias{encTest3}
\docType{package}
\title{
Package to test Unicode support in R CMD Rd2pdf
}
\description{

  This example package and the related patch are about compiling UTF-8
  encoded Rd files to \acronym{PDF} format with the command line tool
  \verb{R CMD Rd2pdf}.

  In practice, not all Unicode characters are supported when using the
  UTF-8 encoding in Rd files.  The help for \code{\link{Rd2pdf}} advices
  one to set the environment variable \sQuote{RD2PDF_INPUTENC} to value
  \sQuote{inputenx} for \dQuote{better support of the UTF-8 encoding}.
  By studying the
  \href{http://mirror.ctan.org/macros/latex/contrib/oberdiek/inputenx.pdf}{manual}
  of the \sQuote{inputenx} LaTeX package, I found that the UTF-8 support
  can further be improved by including the command
  \verb{\input\{ix-utf8enc.dfu\}} in the LaTeX input file.

  The attached patch (see Details) aims to do that for \verb{R CMD Rd2pdf}.
  The patch has been tested to work with this test package.  Without the
  patch, when \verb{R CMD Rd2pdf} is run on this example package, it
  shows the following error message:
  \preformatted{! Package inputenc Error: Unicode char \\u8:ė not set up for use with LaTeX.}
}
\details{
  \preformatted{
Index: src/library/tools/R/Rd2pdf.R
===================================================================
--- src/library/tools/R/Rd2pdf.R	(revision 59731)
+++ src/library/tools/R/Rd2pdf.R	(working copy)
@@ -466,12 +466,17 @@
     inputenc <- Sys.getenv("RD2PDF_INPUTENC", "inputenc")
     ## this needs to be canonical, e.g. 'utf8'
     ## trailer is for detection if we want to edit it later.
+    latex_outputEncoding <- latex_canonical_encoding(outputEncoding)
     setEncoding <-
         paste("\\\\usepackage[",
-              latex_canonical_encoding(outputEncoding), "]\{",
+              latex_outputEncoding, "]\{",
               inputenc, "\} \% @SET ENCODING@", sep="")
     useGraphicx <- "\% \\\\usepackage\{graphicx\} \% @USE GRAPHICX@"
     writeLines(c(setEncoding,
+                 if (inputenc == "inputenx" &&
+                     latex_outputEncoding == "utf8") \{
+                     "\\\\input\{ix-utf8enc.dfu\}"
+                 \},
     		 useGraphicx,
                  if (index) "\\\\makeindex\{\}",
                  "\\\\begin\{document\}"), out)
@@ -545,21 +550,28 @@
     latexEncodings <- unique(latexEncodings)
     latexEncodings <- latexEncodings[!is.na(latexEncodings)]
     cyrillic <- if (nzchar(Sys.getenv("_R_CYRILLIC_TEX_"))) "utf8" \%in\% latexEncodings else FALSE
-    latex_outputEncoding <- latex_canonical_encoding(outputEncoding)
     encs <- latexEncodings[latexEncodings != latex_outputEncoding]
     if (length(encs) || hasFigures || cyrillic) \{
         lines <- readLines(outfile)
+        moreUnicode <- inputenc == "inputenx" && "utf8" \%in\% encs
 	encs <- paste(encs, latex_outputEncoding, collapse=",", sep=",")
 
 	if (!cyrillic) \{
-	    lines[lines == setEncoding] <-
+	    setEncoding2 <-
 		paste0("\\\\usepackage[", encs, "]\{", inputenc, "\}")
 	\} else \{
-	    lines[lines == setEncoding] <-
+	    setEncoding2 <-
 		paste(
 "\\\\usepackage[", encs, "]\{", inputenc, "\}
 \\\\IfFileExists\{t2aenc.def\}\{\\\\usepackage[T2A]\{fontenc\}\}\{\}", sep = "")
 	\}
+	if (moreUnicode) \{
+	    setEncoding2 <-
+		paste0(
+setEncoding2, "
+\\\\input\{ix-utf8enc.dfu\}")
+        \}
+        lines[lines == setEncoding] <- setEncoding2
 	if (hasFigures)
 	    lines[lines == useGraphicx] <- "\\\\usepackage\{graphicx\}\\\\setkeys\{Gin\}\{width=0.7\\\\textwidth\}"
 	writeLines(lines, outfile)
  }
}
\author{
Mikko Korpela
}
\keyword{ package }
